[m-dev.] diff: Put Morphine under GNU/GPL

Erwan Jahier Erwan.Jahier at irisa.fr
Thu Dec 16 21:01:54 AEDT 1999


Hopefully, I will be ready for 0.9.1!
:-)

--
Estimated hours taken: 2

Put Morphine under the GNU/GPL licence. Also replace a few remaining
occurrences of Opium-M by Morphine.

morphine/Licence:
	File containing a copy of the GNU/GPL licence.

morphine/INSTALL-MORPHINE:
morphine/source/*.pl:
morphine/source/*.op:
	Add 2 lines in each file header that state that Morphine is under
	the GNU/GPL Licence.

morphine/copyright.txt:
	Change this file in such a way that Morphine is now under GNU/GPL.


morphine/INSTALL-MORPHINE:
morphine/README:
morphine/source/load_morphine.pl:
morphine/source/load_morphine.pl:
morphine/source/morphine_kernel.op
	Replace a few remaining occurrences of Opium-M by Morphine.



Index: INSTALL-MORPHINE
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/INSTALL-MORPHINE,v
retrieving revision 1.1
diff -u -d -u -r1.1 INSTALL-MORPHINE
--- INSTALL-MORPHINE	1999/11/11 04:52:01	1.1
+++ INSTALL-MORPHINE	1999/12/16 09:53:40
@@ -1,16 +1,18 @@
 #!/bin/sh
 # Copyright (C) 1999 INRIA/INSA.
+# This file may only be copied under the terms of the GNU Library General
+# Public License - see the file License in the Morphine distribution.
 #
 # Author : Erwan Jahier <jahier at irisa.fr>
 #
-# This script creates the Opium-M script.
+# This script creates the Morphine script.
 
 
 
-MERCURY_OPIUM_DIR=`pwd`
-export MERCURY_OPIUM_DIR 
+MERCURY_MORPHINE_DIR=`pwd`
+export MERCURY_MORPHINE_DIR 
 cd scripts
-rm -f Opium-M
+rm -f morphine
 
 # Get the Mercury library path (needed in source scenario)
 MmcDefault=/soft/mercury/library
@@ -23,24 +25,26 @@
         *)    LIB_MERCURY=$RESPONSE;;
 esac
 
-cat << EOF >> Opium-M
+cat << EOF >> morphine
 #!/bin/sh
 # Copyright (C) 1999 INRIA/INSA. 
+# This file may only be copied under the terms of the GNU Library General
+# Public License - see the file License in the Morphine distribution.
 #  
 # Author : Erwan Jahier <jahier at irisa.fr> 
 # 
-# Script generated by INSTALL-OPIUM-M. 
+# Script generated by INSTALL-MORPHINE. 
 
 Help=" 
-Name:  Opium-M 
-Usage: Opium-M [--no-banner]
+Name:  morphine 
+Usage: morphine [--no-banner]
 Description: 
-       Runs Opium-M, the Mercury trace analyser. 
+       Runs morphine, the Mercury trace analysis system. 
 "
 
-#This variable should contain the path where Opium-M has been installed 
-MERCURY_OPIUM_DIR=$MERCURY_OPIUM_DIR
-export MERCURY_OPIUM_DIR 
+#This variable should contain the path where Morphine has been installed 
+MERCURY_MORPHINE_DIR=$MERCURY_MORPHINE_DIR
+export MERCURY_MORPHINE_DIR 
 
 #This variable should contain the path of the mercury library source files  
 #(which is needed in the source scenario)  
@@ -48,9 +52,9 @@
 export LIB_MERCURY 
  
 case \$1 in
-    --no-banner) COMMAND="eclipse -b ${MERCURY_OPIUM_DIR}/source/load_opium_without_banner.pl " ;;
+    --no-banner) COMMAND="eclipse -b ${MERCURY_MORPHINE_DIR}/source/load_morphine_without_banner.pl " ;;
 
-     *) COMMAND="eclipse -b ${MERCURY_OPIUM_DIR}/source/load_opium.pl " ;;
+     *) COMMAND="eclipse -b ${MERCURY_MORPHINE_DIR}/source/load_morphine.pl " ;;
 esac
 
 exec \$COMMAND 
@@ -61,21 +65,21 @@
 
 echo "Compiling the Mercury program listing.m..."
 [ -d bin ] || mkdir bin
-cd ${MERCURY_OPIUM_DIR}/source
+cd ${MERCURY_MORPHINE_DIR}/source
 mmake listing.depend
 mmake listing
-mv ${MERCURY_OPIUM_DIR}/source/listing ${MERCURY_OPIUM_DIR}/bin/
-chmod a+x ${MERCURY_OPIUM_DIR}/bin/listing
+mv ${MERCURY_MORPHINE_DIR}/source/listing ${MERCURY_MORPHINE_DIR}/bin/
+chmod a+x ${MERCURY_MORPHINE_DIR}/bin/listing
 mmake listing.realclean
 
-chmod a+x ${MERCURY_OPIUM_DIR}/scripts/Opium-M
+chmod a+x ${MERCURY_MORPHINE_DIR}/scripts/morphine
 
-echo "Compiling Opium-M files..."
-eclipse -b ${MERCURY_OPIUM_DIR}/source/make_scenario.pl
+echo "Compiling Morphine files..."
+eclipse -b ${MERCURY_MORPHINE_DIR}/source/make_scenario.pl
 
 echo ""
-echo "  Don't forget to add ${MERCURY_OPIUM_DIR}/scripts and"
-echo "  ${MERCURY_OPIUM_DIR}/bin to your PATH."
+echo "  Don't forget to add ${MERCURY_MORPHINE_DIR}/scripts and"
+echo "  ${MERCURY_MORPHINE_DIR}/bin to your PATH."
 echo "  Make sure that the executables mmc and eclipse are accessible "
 echo "  from your PATH too."
 
Index: README
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/README,v
retrieving revision 1.2
diff -u -d -u -r1.2 README
--- README	1999/12/14 23:51:43	1.2
+++ README	1999/12/16 09:53:43
@@ -1,44 +1,43 @@
-# Copyright (C) 1999 INRIA/INSA.
 
-* Opium-M, a trace analysis system for Mercury
+* Morphine, a trace analysis system for Mercury
 
 Program execution traces given by traditional debuggers provide programmers
 with useful pieces of information. However, using them requires to analyse by
-hand huge amounts of information. Opium-M is connected to the traditional
+hand huge amounts of information. Morphine is connected to the traditional
 tracer of Mercury; it allows execution trace analyses to be automated. It
 provides a relational trace query language based on Prolog which enables users
-to specify precisely what they want to see in the trace. Opium-M, then,
+to specify precisely what they want to see in the trace. Morphine, then,
 automatically filters out information irrelevant for the users.
 
-Opium-M provides users a langage to write their own debugging primitives
+Morphine provides users a langage to write their own debugging primitives
 (Prolog + 2 primitives connected to the Mercury trace system) and their own
 monitors (see the `collect' command).
 
 				-o-
 
-* Opium-M installation
+* Morphine installation
 
-To install Opium-M, you just need to:
+To install Morphine, you just need to:
 
-1) Run the script `INSTALL-OPIUM-M' (that creates the `Opium-M' script in 
-   the `opium_m/scripts/' directory).
-2) Add directories ` opium_m/scripts/' and `opium_m/bin/' in your `PATH' 
+1) Run the script `INSTALL-MORPHINE' (that creates the `morphine' script in 
+   the `morphine/scripts/' directory).
+2) Add directories ` morphine/scripts/' and `morphine/bin/' in your `PATH' 
    environment variable. Make sure that the executables `mmc' and `eclipse' 
    are also accessible from your `PATH'. 
 
 
-Note that Opium-M requires ECLiPSe, a Prolog system which is free to
+Note that Morphine requires ECLiPSe, a Prolog system which is free to
 universities and non-profit research institutions. You can download it at
 `http://www.icparc.ic.ac.uk/eclipse/'. Also make sure that the package
 eclipse_misc.tgz has been downloaded (i.e. if there exists a directory named
-`lib_pd' in the ECLiPSe installation directory); Opium-M needs it.
+`lib_pd' in the ECLiPSe installation directory); Morphine needs it.
 
-Opium-M does not require Mercury to be installed, but you might also want to
+Morphine does not require Mercury to be installed, but you might also want to
 install it ;-)
 
 				-o-
 
-* The current release of Opium-M has been tested with the following 
+* The current release of Morphine has been tested with the following 
   configurations: 
 
 o Architectures: sparc/Solaris2.[5,6,7] and i686/Linux kernel 2.0
@@ -47,7 +46,7 @@
 
 				-o-
 
-For more information about Opium-M, you can have a look at the Opium-M
+For more information about Morphine, you can have a look at the Morphine
 web site:
 
 http://www.irisa.fr/lande/jahier/download.html
Index: copyright.txt
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/copyright.txt,v
retrieving revision 1.2
diff -u -d -u -r1.2 copyright.txt
--- copyright.txt	1999/12/15 13:39:30	1.2
+++ copyright.txt	1999/12/16 09:53:43
@@ -1,7 +1,7 @@
 
 
-The software Morphine in its 0.2 release of November 1999, hereinafter referred
-to as « the software » has been designed and produced by Erwan Jahier and
+The software Morphine in its 0.2 release of December 1999, hereinafter referred
+to as " the software " has been designed and produced by Erwan Jahier and
 Mireille Ducassé, researchers of the LANDE project, a research project of the
 National Computer and Automatics Institute - INRIA - Rennes Research Unit.
 
@@ -19,42 +19,18 @@
 (APP) under the number XXX
 
 This Software is a copyright INRIA/INSA - 1999.
-
-INRIA/INSA holds all the ownership rights on the Software. The scientific community
-is asked to use the SOFTWARE in order to test and evaluate it.
-
-INRIA/INSA freely grants the right to use the Software. Any use or reproduction of
-this Software to obtain profit or for commercial ends being subject to
-obtaining the prior express authorisation of INRIA/INSA.
-
-INRIA/INSA authorises any reproduction of this Software
-
-- in limits defined in clauses 9 and 10 of the Berne agreement for the
-  protection of literary and artistic works respectively specify in their
-  paragraphs 2 and 3 authorising only the reproduction and quoting of works on
-  the condition that :
- 
-- "this reproduction does not adversely affect the normal exploitation of the
-  work or cause any unjustified prejudice to the legitimate interests of the
-  author".
-
-- "that the quotations given by way of illustration and/or tuition conform to
-  the proper uses and that it mentions the source and name of the author if
-  this name features in the source",
 
-- under the condition that this file is included with any reproduction.
- 
- Any commercial use made without obtaining the prior express agreement of
- INRIA/INSA would therefore constitute a fraudulent imitation.
+The files of the Software may only be copied under the terms of the GNU Library
+General Public License - see the file Licence in the Morphine distribution.
 
-the Software being currently developed, INRIA/INSA is assuming no liability, and
+The Software being currently developed, INRIA/INSA is assuming no liability, and
 should not be responsible, in any manner or any case, for any direct or
 indirect damages sustained by the user.
  
 
 
 %------------------------------------------------------------------------------%
-Le logiciel Morphine dans sa version 0.2 (novembre 1999), ci-après dénommé "Le
+Le logiciel Morphine dans sa version 0.2 (décembre 1999), ci-après dénommé "Le
 LOGICIEL", a été conçu et réalisé par Erwan Jahier et Mireille Ducassé,
 chercheurs du projet LANDE, projet de recherche de l'Institut National de
 Recherche en Informatique et en Automatique - INRIA - Unité de Recherche de
@@ -74,32 +50,10 @@
 sous le numéro XXX
 
 Ce Logiciel est couvert par le copyright  INRIA/INSA - 1999.
-
-L'INRIA/INSA détient tous les droits de propriété sur le LOGICIEL, il souhaite que
-la communauté scientifique l'utilise afin de le tester et de l'évaluer.
-
-L'INRIA/INSA donne gracieusement le droit d'utiliser ce Logiciel. Toute utilisation
-dans un but lucratif ou a des fins commerciales est interdite sauf autorisation
-expresse et préalable de l'INRIA/INSA.
- 
-L'INRIA/INSA autorise toute reproduction de ce Logiciel :
-
-- dans les limites définies aux articles 9 et 10 de la convention de Berne pour
-  la protection des oeuvres littéraires et artistiques pris respectivement dans
-  leurs alinéas 2 et 3, c'est-à-dire à condition :
-
-- " qu'une telle reproduction ne porte pas atteinte à l'exploitation normale de
-  l'oeuvre, ni ne cause un préjudice injustifié aux intérêts légitimes de
-  
-- " que les citations à titre d'illustration et/ou d'un enseignement soient
-  conformes aux bons usages et qu'il soit fait mention de la source et du nom
-  de l'auteur, si ce nom figure dans la source",
-         
-- à condition que toute reproduction soit accompagnée du présent fichier.
 
-Toute utilisation hors des limites précisées ci-dessus et réalisée sans
-l'accord expresse préalable de l'INRIA/INSA constituerait donc le délit de
-contrefaçon.
+Les fichier de ce logiciel peuvent être copiés seulement sous les termes de la
+license "GNU Library General Public License" - voir le fichier Licence dans la
+distribution de Morphine.
 
 Le LOGICIEL étant un produit en cours de développement, l'INRIA/INSA ne saurait
 assurer aucune responsabilité et notamment en aucune manière et en aucun cas,
Index: source/browse.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/browse.op,v
retrieving revision 1.1
diff -u -d -u -r1.1 browse.op
--- source/browse.op	1999/11/11 04:52:19	1.1
+++ source/browse.op	1999/12/16 09:53:43
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier
 % File   : browse.op
Index: source/collect.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/collect.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 collect.op
--- source/collect.op	1999/12/15 13:40:46	1.2
+++ source/collect.op	1999/12/16 09:53:46
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier
 % File   : collect.op
Index: source/collect__control_flow_graph
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/collect__control_flow_graph,v
retrieving revision 1.1
diff -u -d -u -r1.1 collect__control_flow_graph
--- source/collect__control_flow_graph	1999/11/11 04:52:20	1.1
+++ source/collect__control_flow_graph	1999/12/16 09:53:46
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/collect__dynamic_call_graph
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/collect__dynamic_call_graph,v
retrieving revision 1.1
diff -u -d -u -r1.1 collect__dynamic_call_graph
--- source/collect__dynamic_call_graph	1999/11/11 04:52:20	1.1
+++ source/collect__dynamic_call_graph	1999/12/16 09:53:46
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/control_flow.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/control_flow.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 control_flow.op
--- source/control_flow.op	1999/12/15 13:40:46	1.2
+++ source/control_flow.op	1999/12/16 09:53:47
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier
 % File   : control_flow.op
Index: source/coprocess.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/coprocess.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 coprocess.op
--- source/coprocess.op	1999/12/15 13:40:46	1.2
+++ source/coprocess.op	1999/12/16 09:53:47
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 %
 % Author : Erwan Jahier <jahier at irisa.fr>
 % 
Index: source/current_arg.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/current_arg.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 current_arg.op
--- source/current_arg.op	1999/12/15 13:40:46	1.2
+++ source/current_arg.op	1999/12/16 09:53:48
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 %
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/current_slots.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/current_slots.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 current_slots.op
--- source/current_slots.op	1999/12/15 13:40:47	1.2
+++ source/current_slots.op	1999/12/16 09:53:50
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 %
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/display.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/display.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 display.op
--- source/display.op	1999/12/15 13:40:47	1.2
+++ source/display.op	1999/12/16 09:53:53
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 %
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/event_attributes.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/event_attributes.op,v
retrieving revision 1.1
diff -u -d -u -r1.1 event_attributes.op
--- source/event_attributes.op	1999/11/11 04:52:22	1.1
+++ source/event_attributes.op	1999/12/16 09:53:55
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 %
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/exec_control.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/exec_control.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 exec_control.op
--- source/exec_control.op	1999/12/15 13:40:47	1.2
+++ source/exec_control.op	1999/12/16 09:53:56
@@ -1,5 +1,7 @@
 %--------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 %
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/forward_move.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/forward_move.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 forward_move.op
--- source/forward_move.op	1999/12/15 13:40:47	1.2
+++ source/forward_move.op	1999/12/16 09:53:58
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier
 % File   : forward_move.op
Index: source/interactive_queries.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/interactive_queries.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 interactive_queries.op
--- source/interactive_queries.op	1999/12/15 13:40:47	1.2
+++ source/interactive_queries.op	1999/12/16 09:53:59
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier
 % File   : interactive_queries.op
Index: source/load_morphine_without_banner.pl
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/load_morphine_without_banner.pl,v
retrieving revision 1.1
diff -u -d -u -r1.1 load_morphine_without_banner.pl
--- source/load_morphine_without_banner.pl	1999/11/11 04:52:23	1.1
+++ source/load_morphine_without_banner.pl	1999/12/16 09:54:01
@@ -1,9 +1,11 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
-:- compile("./load_opium.pl").
+:- compile("./load_morphine.pl").
 
 
 % Remove the Eclipse banner (for non-regression test)
Index: source/load_scenario.pl
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/load_scenario.pl,v
retrieving revision 1.2
diff -u -d -u -r1.2 load_scenario.pl
--- source/load_scenario.pl	1999/12/15 13:40:48	1.2
+++ source/load_scenario.pl	1999/12/16 09:54:02
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Authors : Erwan Jahier <jahier at irisa.fr>, 
 %           Mireille Ducassé <ducasse at irisa.fr>
Index: source/make_scenario.pl
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/make_scenario.pl,v
retrieving revision 1.2
diff -u -d -u -r1.2 make_scenario.pl
--- source/make_scenario.pl	1999/12/15 13:40:48	1.2
+++ source/make_scenario.pl	1999/12/16 09:54:03
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Authors : Erwan Jahier <jahier at irisa.fr>, 
 %           Mireille Ducassé <ducasse at irisa.fr>
Index: source/morphine_kernel.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/morphine_kernel.op,v
retrieving revision 1.1
diff -u -d -u -r1.1 morphine_kernel.op
--- source/morphine_kernel.op	1999/11/11 04:52:24	1.1
+++ source/morphine_kernel.op	1999/12/16 09:54:03
@@ -1,12 +1,14 @@
 %--------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 %
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
 
 opium_scenario(
-	name		: opium_m_kernel,
-	files		: [	opium_m_kernel,
+	name		: morphine_kernel,
+	files		: [	morphine_kernel,
 				forward_move,
 				current_slots,
 				current_arg,
@@ -17,7 +19,7 @@
 				browse],
 	scenarios	: [],
 	message		:
-"Scenario opium_m_kernel contains all the basic mechanisms of Opium-M \
+"Scenario opium_m_kernel contains all the basic mechanisms of Morphine \
 which are needed to debug Mercury programs. \n\
 "
 	).
Index: source/source.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/source.op,v
retrieving revision 1.2
diff -u -d -u -r1.2 source.op
--- source/source.op	1999/12/15 13:40:49	1.2
+++ source/source.op	1999/12/16 09:54:08
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/step_by_step.op
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/step_by_step.op,v
retrieving revision 1.1
diff -u -d -u -r1.1 step_by_step.op
--- source/step_by_step.op	1999/11/11 04:52:27	1.1
+++ source/step_by_step.op	1999/12/16 09:54:08
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 %
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
Index: source/util.pl
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/util.pl,v
retrieving revision 1.2
diff -u -d -u -r1.2 util.pl
--- source/util.pl	1999/12/15 13:40:49	1.2
+++ source/util.pl	1999/12/16 09:54:08
@@ -1,5 +1,7 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Authors : Erwan Jahier <jahier at irisa.fr>,
 %           Mireille Ducassé <ducasse at irisa.fr>

Index: source/load_morphine.pl
===================================================================
RCS file: /home/mercury1/repository/mercury/extras/morphine/source/load_morphine.pl,v
retrieving revision 1.1
diff -u -d -u -r1.1 load_morphine.pl
--- source/load_morphine.pl	1999/11/11 04:52:23	1.1
+++ source/load_morphine.pl	1999/12/16 09:54:01
@@ -1,25 +1,27 @@
 %------------------------------------------------------------------------------%
 % Copyright (C) 1999 INRIA/INSA.
+% This file may only be copied under the terms of the GNU Library General
+% Public License - see the file License in the Morphine distribution.
 % 
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
 % This is the first file to be loaded when Opium-M is run.
 % It is called from the Opium-M script.
 
 
 %------------------------------------------------------------------------------%
-% re-definition of opium_answer/2
+% re-definition of morphine_answer/2
 % defined in ~/sepia/workdir/sepia/pl/boot_bips.pl
 
-opium_answer(_, yes).
-opium_answer(_, no) :-
+morphine_answer(_, yes).
+morphine_answer(_, no) :-
         write(toplevel_output, 'no.\n').
-opium_answer(_, no_answer) :-
+morphine_answer(_, no_answer) :-
         write(toplevel_output, 'no (more) solution.\n').
-opium_answer(_, last_yes).
-opium_answer(_, last_answer) :-
+morphine_answer(_, last_yes).
+morphine_answer(_, last_answer) :-
         write(toplevel_output, '\n').
-opium_answer(_, more_answers) :-
+morphine_answer(_, more_answers) :-
         write(toplevel_output, '     More? (;) '),
         flush(toplevel_output),
         tyi(toplevel_input, C),
@@ -32,19 +34,19 @@
 		flush(toplevel_output)
 	).
 
-:- set_error_handler(156, opium_answer/2).
+:- set_error_handler(156, morphine_answer/2).
 
 
 %------------------------------------------------------------------------------%
-% Load Opium-M.
-:- getenv('MERCURY_OPIUM_DIR', Dir),
+% Load Morphine.
+:- getenv('MERCURY_MORPHINE_DIR', Dir),
 	append_strings(Dir, "/source/load_scenario.pl", MakeFile),
 	compile(MakeFile).
 
-% Initialise the Opium-M session
-:- init_opium_session.
+% Initialise the Morphine session
+:- init_morphine_session.
 
-:- set_flag(toplevel_module, 'Opium-M').
+:- set_flag(toplevel_module, morphine).
 
 %------------------------------------------------------------------------------%
 
@@ -1,25 +1,27 @@
 % Author : Erwan Jahier <jahier at irisa.fr>
 %
-% This is the first file to be loaded when Opium-M is run.
-% It is called from the Opium-M script.
+% This is the first file to be loaded when Morphine is run.
+% It is called from the morphine script.
 
 
-- 
R1.


--------------------------------------------------------------------------
mercury-developers mailing list
Post messages to:       mercury-developers at cs.mu.oz.au
Administrative Queries: owner-mercury-developers at cs.mu.oz.au
Subscriptions:          mercury-developers-request at cs.mu.oz.au
--------------------------------------------------------------------------



More information about the developers mailing list